
# Simple CLI for python

This CLI uses only native python libraries, which means that you don't need to use "pip install" in your projects, but, it is only implemented and tested on Windows.

## Features

- .ppm image support
- support for simple geometry
- support for the text

## Documentation

See documentation.py

## Demo

https://user-images.githubusercontent.com/101042422/178258748-15366975-d090-4421-b92e-b876581c85a7.mp4

## Authors

- [@bruh](https://www.instagram.com/killianfrr/)